@@ -12,13 +12,15 @@ class EntityType(IntEnum):
 
 class Label:
     def __init__(self, dict):
-        assert_enum_value_in_dict(dict, 'entity_type', EntityType)
+        entityTypeVal = dict.get('entity_type', dict.get('entityType'))
+        self.entity_type = EntityType[entityTypeVal.title()] if type(
+            entityTypeVal) == str else EntityType(entityTypeVal)
+        assert_enum_value_in_dict(self.__dict__, 'entity_type', EntityType)
         assert_non_empty_string_in_dict(dict, 'entity')
-        assert_non_empty_string_in_dict(dict, 'label')
         self.entity = dict['entity']
         self.confidence = dict['confidence']
-        self.entity_type = dict['entity_type']
         self.label = dict['label']
+        self.remove = dict.get('remove', False)
 
     def toDict(self):
         d = dict(self.__dict__, **{
